@@ -366,9 +366,9 @@ TQString GpsimProcessor::generateSymbolFile( const TQString &fileName, TQObject
 		if (receiver)
 		{
 			if (successMember)
-				connect( pc, TQT_SIGNAL(successful()), receiver, successMember );
+				connect( pc, TQ_SIGNAL(successful()), receiver, successMember );
 			if (failMember)
-				connect( pc, TQT_SIGNAL(failed()), receiver, failMember );
+				connect( pc, TQ_SIGNAL(failed()), receiver, failMember );
 		}
 		
 		return TQString(hexFile).replace( ".hex", ".cod" );
@@ -386,9 +386,9 @@ TQString GpsimProcessor::generateSymbolFile( const TQString &fileName, TQObject
 		if (receiver)
 		{
 			if (successMember)
-				connect( pc, TQT_SIGNAL(successful()), receiver, successMember );
+				connect( pc, TQ_SIGNAL(successful()), receiver, successMember );
 			if (failMember)
-				connect( pc, TQT_SIGNAL(failed()), receiver, failMember );
+				connect( pc, TQ_SIGNAL(failed()), receiver, failMember );
 		}
 		
 		return TQString(fileName).replace(".asm",".cod");
@@ -406,9 +406,9 @@ TQString GpsimProcessor::generateSymbolFile( const TQString &fileName, TQObject
 		if (receiver)
 		{
 			if (successMember)
-				connect( pc, TQT_SIGNAL(successful()), receiver, successMember );
+				connect( pc, TQ_SIGNAL(successful()), receiver, successMember );
 			if (failMember)
-				connect( pc, TQT_SIGNAL(failed()), receiver, failMember );
+				connect( pc, TQ_SIGNAL(failed()), receiver, failMember );
 		}
 		
 		return TQString(fileName).replace(".c",".cod");
@@ -432,9 +432,9 @@ void GpsimProcessor::compileMicrobe( const TQString &filename, TQObject *receive
 	if (receiver)
 	{
 		if (successMember)
-			connect( pc, TQT_SIGNAL(successful()), receiver, successMember );
+			connect( pc, TQ_SIGNAL(successful()), receiver, successMember );
 		if (failMember)
-			connect( pc, TQT_SIGNAL(failed()), receiver, failMember );
+			connect( pc, TQ_SIGNAL(failed()), receiver, failMember );
 	}
 }
 //END class GpsimProcessor
@@ -452,7 +452,7 @@ GpsimDebugger::GpsimDebugger( Type type, GpsimProcessor * gpsim )
 	m_stackLevelLowerBreak = -1;
 	m_addressSize = 0;
 	
-	connect( m_pGpsim, TQT_SIGNAL(runningStatusChanged(bool )), this, TQT_SLOT(gpsimRunningStatusChanged(bool )) );
+	connect( m_pGpsim, TQ_SIGNAL(runningStatusChanged(bool )), this, TQ_SLOT(gpsimRunningStatusChanged(bool )) );
 	
 	if ( type == HLLDebugger )
 	{
