@@ -34,16 +34,16 @@ FlowCodeView::FlowCodeView( FlowCodeDocument * flowCodeDocument, ViewContainer *
 	m->insertItem( TDEGlobal::iconLoader()->loadIcon( "convert_to_assembly", TDEIcon::Small ), i18n("Assembly"), FlowCodeDocument::AssemblyOutput );
 	m->insertItem( TDEGlobal::iconLoader()->loadIcon( "convert_to_hex", TDEIcon::Small ), i18n("Hex"), FlowCodeDocument::HexOutput );
 	m->insertItem( TDEGlobal::iconLoader()->loadIcon( "convert_to_pic", TDEIcon::Small ), i18n("PIC (upload)"), FlowCodeDocument::PICOutput );
-	connect( m, TQT_SIGNAL(activated(int)), flowCodeDocument, TQT_SLOT(slotConvertTo(int)) );
+	connect( m, TQ_SIGNAL(activated(int)), flowCodeDocument, TQ_SLOT(slotConvertTo(int)) );
 	//END Convert To * Actions
 	
 	
 	
 	
-// 	new TDEAction( i18n("Convert to Microbe"), "convert_to_microbe", TQt::Key_F7, flowCodeDocument, TQT_SLOT(convertToMicrobe()), ac, "tools_to_microbe" );
-// 	new TDEAction( i18n("Convert to Assembly"), "convert_to_assembly", TQt::Key_F8, flowCodeDocument, TQT_SLOT(convertToAssembly()), ac, "tools_to_assembly" );
-// 	new TDEAction( i18n("Convert to Hex"), "convert_to_hex", TQt::Key_F9, flowCodeDocument, TQT_SLOT(convertToHex()), ac, "tools_to_hex" );
-// 	new TDEAction( i18n("Upload PIC Program"), "convert_to_pic", 0, flowCodeDocument, TQT_SLOT(convertToPIC()), ac, "tools_to_pic" );
+// 	new TDEAction( i18n("Convert to Microbe"), "convert_to_microbe", TQt::Key_F7, flowCodeDocument, TQ_SLOT(convertToMicrobe()), ac, "tools_to_microbe" );
+// 	new TDEAction( i18n("Convert to Assembly"), "convert_to_assembly", TQt::Key_F8, flowCodeDocument, TQ_SLOT(convertToAssembly()), ac, "tools_to_assembly" );
+// 	new TDEAction( i18n("Convert to Hex"), "convert_to_hex", TQt::Key_F9, flowCodeDocument, TQ_SLOT(convertToHex()), ac, "tools_to_hex" );
+// 	new TDEAction( i18n("Upload PIC Program"), "convert_to_pic", 0, flowCodeDocument, TQ_SLOT(convertToPIC()), ac, "tools_to_pic" );
 	
 	
 	
