@@ -22,7 +22,7 @@ which colours are displayed to be changed.
 */
 class ColorCombo : public TQComboBox
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	TQ_PROPERTY( TQColor color READ color WRITE setColor )
 
