@@ -23,7 +23,7 @@
 #include <tqwhatsthis.h>
 
 MicroSelectWidget::MicroSelectWidget( TQWidget* parent, const char* name, WFlags )
-	: TQGroupBox( 4, Qt::Horizontal, i18n("Microprocessor"), parent, name )
+	: TQGroupBox( 4, TQt::Horizontal, i18n("Microprocessor"), parent, name )
 {
 	m_allowedAsmSet = AsmInfo::AsmSetAll;
 	m_allowedGpsimSupport = m_allowedFlowCodeSupport = m_allowedMicrobeSupport = MicroInfo::AllSupport;
@@ -46,7 +46,7 @@ MicroSelectWidget::MicroSelectWidget( TQWidget* parent, const char* name, WFlags
 	m_pMicro->setAutoCompletion(true);
 	updateFromAllowed();
 	setMicro("P16F84");
-	connect( m_pMicroFamily, TQT_SIGNAL(activated(const TQString & )), this, TQT_SLOT(microFamilyChanged(const TQString& )) );
+	connect( m_pMicroFamily, TQ_SIGNAL(activated(const TQString & )), this, TQ_SLOT(microFamilyChanged(const TQString& )) );
 }
 
 
