@@ -61,7 +61,7 @@ class OutputMethodInfo
 */
 class OutputMethodDlg : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		/**
